@@ -16,6 +16,7 @@ from . import DriverError
 
 from twisted.internet.defer import inlineCallbacks, returnValue
 
+
 if not six.PY3:
     import tkFileDialog as filedialog
     from StringIO import StringIO
@@ -67,10 +68,7 @@ class ReadNGCTelemetry(object):
         pattern = '\D*(\d*).*.fits'
         try:
             run_number = int(re.match(pattern, newDataFileName).group(1))
-            if exposure_state == "success":
-                self.run = run_number
-            elif exposure_state == "aborted":
-                # We use abort instead of end. Don't know why
+            if exposure_state in ["success", "aborted", 'inactive', 'failure']:
                 self.run = run_number
             elif exposure_state == "integrating":
                 self.run = run_number + 1
@@ -179,7 +177,7 @@ def postJSON(g, data):
 
     ok = True
     try:
-        yield session.call('hipercam.ngc.rpc.load_setup', data)
+        ok, status_msg = yield session.call('hipercam.ngc.rpc.load_setup', data)
     except Exception as err:
         ok, status_msg = False, str(err)
 
